export declare enum LogFormat {
    NONE = "",
    STAT = "--stat",
    NUM_STAT = "--numstat",
    NAME_ONLY = "--name-only",
    NAME_STATUS = "--name-status"
}
export declare function logFormatFromCommand(customArgs: string[]): LogFormat;
export declare function isLogFormat(customArg: string | unknown): boolean;
