import { PullResult } from '../../../typings';
import { Maybe, StringTask } from '../types';
export declare function pullTask(remote: Maybe<string>, branch: Maybe<string>, customArgs: string[]): StringTask<PullResult>;
