export declare function statSync(...args: any[]): any;
export declare function addStatSyncMock(fn: any): void;
export declare function assertMocksUsed(): void;
declare const mockFs: {
    statSync: typeof statSync;
};
export default mockFs;
