export default {
  settings: 'Settings',
  auth: 'Authentication',
  memory: {
    display: 'hidden',
  },
  'qwen-ignore': 'Ignoring Files',
  'trusted-folders': 'Trusted Folders',
  themes: 'Themes',
};
