import { BranchMultiDeleteResult } from '../../../typings';
import { TaskParser } from '../types';
import { ExitCodes } from '../utils';
export declare const parseBranchDeletions: TaskParser<string, BranchMultiDeleteResult>;
export declare function hasBranchDeletionError(data: string, processExitCode: ExitCodes): boolean;
